pub struct ClawbackClaimableBalanceOp {
pub balance_id: ClaimableBalanceId,
}Expand description
ClawbackClaimableBalanceOp is an XDR Struct defined as:
struct ClawbackClaimableBalanceOp
{
ClaimableBalanceID balanceID;
};Fields
balance_id: ClaimableBalanceIdTrait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for ClawbackClaimableBalanceOp
impl<'arbitrary> Arbitrary<'arbitrary> for ClawbackClaimableBalanceOp
Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourcefn size_hint(depth: usize) -> (usize, Option<usize>)
fn size_hint(depth: usize) -> (usize, Option<usize>)
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourcefn try_size_hint(
depth: usize,
) -> Result<(usize, Option<usize>), MaxRecursionReached>
fn try_size_hint( depth: usize, ) -> Result<(usize, Option<usize>), MaxRecursionReached>
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourceimpl Clone for ClawbackClaimableBalanceOp
impl Clone for ClawbackClaimableBalanceOp
Sourcefn clone(&self) -> ClawbackClaimableBalanceOp
fn clone(&self) -> ClawbackClaimableBalanceOp
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClawbackClaimableBalanceOp
impl Debug for ClawbackClaimableBalanceOp
Sourceimpl Default for ClawbackClaimableBalanceOp
impl Default for ClawbackClaimableBalanceOp
Sourcefn default() -> ClawbackClaimableBalanceOp
fn default() -> ClawbackClaimableBalanceOp
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ClawbackClaimableBalanceOp
impl<'de> Deserialize<'de> for ClawbackClaimableBalanceOp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ClawbackClaimableBalanceOp
impl Hash for ClawbackClaimableBalanceOp
Sourceimpl JsonSchema for ClawbackClaimableBalanceOp
impl JsonSchema for ClawbackClaimableBalanceOp
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ClawbackClaimableBalanceOp
impl Ord for ClawbackClaimableBalanceOp
Sourcefn cmp(&self, other: &ClawbackClaimableBalanceOp) -> Ordering
fn cmp(&self, other: &ClawbackClaimableBalanceOp) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClawbackClaimableBalanceOp
impl PartialEq for ClawbackClaimableBalanceOp
Sourcefn eq(&self, other: &ClawbackClaimableBalanceOp) -> bool
fn eq(&self, other: &ClawbackClaimableBalanceOp) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClawbackClaimableBalanceOp
impl PartialOrd for ClawbackClaimableBalanceOp
Sourceimpl ReadXdr for ClawbackClaimableBalanceOp
impl ReadXdr for ClawbackClaimableBalanceOp
Sourcefn read_xdr<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
std only.Read the XDR and construct the type. Read more
Sourcefn read_xdr_base64<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr_base64<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
base64 only.Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
std only.Read the XDR and construct the type, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_base64_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr_base64_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
base64 only.Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_into<R: Read>(&mut self, r: &mut Limited<R>) -> Result<(), Error>
fn read_xdr_into<R: Read>(&mut self, r: &mut Limited<R>) -> Result<(), Error>
Available on crate feature
std only.Read the XDR and construct the type. Read more
Sourcefn read_xdr_into_to_end<R: Read>(
&mut self,
r: &mut Limited<R>,
) -> Result<(), Error>
fn read_xdr_into_to_end<R: Read>( &mut self, r: &mut Limited<R>, ) -> Result<(), Error>
Available on crate feature
std only.Read the XDR into the existing value, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_iter<R: Read>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘ
fn read_xdr_iter<R: Read>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘ
Available on crate feature
std only.Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type. Read more
Sourcefn read_xdr_base64_iter<R: Read>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘ
fn read_xdr_base64_iter<R: Read>( r: &mut Limited<R>, ) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘ
Available on crate feature
base64 only.Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type.
Sourceimpl WriteXdr for ClawbackClaimableBalanceOp
impl WriteXdr for ClawbackClaimableBalanceOp
impl Eq for ClawbackClaimableBalanceOp
impl StructuralPartialEq for ClawbackClaimableBalanceOp