pub struct ScpNomination {
pub quorum_set_hash: Hash,
pub votes: VecM<Value>,
pub accepted: VecM<Value>,
}Expand description
ScpNomination is an XDR Struct defined as:
struct SCPNomination
{
Hash quorumSetHash; // D
Value votes<>; // X
Value accepted<>; // Y
};Fields
quorum_set_hash: Hashvotes: VecM<Value>accepted: VecM<Value>Trait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for ScpNomination
impl<'arbitrary> Arbitrary<'arbitrary> for ScpNomination
Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourcefn size_hint(depth: usize) -> (usize, Option<usize>)
fn size_hint(depth: usize) -> (usize, Option<usize>)
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourcefn try_size_hint(
depth: usize,
) -> Result<(usize, Option<usize>), MaxRecursionReached>
fn try_size_hint( depth: usize, ) -> Result<(usize, Option<usize>), MaxRecursionReached>
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourceimpl Clone for ScpNomination
impl Clone for ScpNomination
Sourcefn clone(&self) -> ScpNomination
fn clone(&self) -> ScpNomination
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScpNomination
impl Debug for ScpNomination
Sourceimpl Default for ScpNomination
impl Default for ScpNomination
Sourcefn default() -> ScpNomination
fn default() -> ScpNomination
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ScpNomination
impl<'de> Deserialize<'de> for ScpNomination
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ScpNomination
impl Hash for ScpNomination
Sourceimpl JsonSchema for ScpNomination
impl JsonSchema for ScpNomination
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ScpNomination
impl Ord for ScpNomination
Sourcefn cmp(&self, other: &ScpNomination) -> Ordering
fn cmp(&self, other: &ScpNomination) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ScpNomination
impl PartialEq for ScpNomination
Sourcefn eq(&self, other: &ScpNomination) -> bool
fn eq(&self, other: &ScpNomination) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ScpNomination
impl PartialOrd for ScpNomination
Sourceimpl ReadXdr for ScpNomination
impl ReadXdr for ScpNomination
Sourcefn read_xdr<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
std only.Read the XDR and construct the type. Read more
Sourcefn read_xdr_base64<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr_base64<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
base64 only.Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
std only.Read the XDR and construct the type, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_base64_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr_base64_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
base64 only.Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_into<R: Read>(&mut self, r: &mut Limited<R>) -> Result<(), Error>
fn read_xdr_into<R: Read>(&mut self, r: &mut Limited<R>) -> Result<(), Error>
Available on crate feature
std only.Read the XDR and construct the type. Read more
Sourcefn read_xdr_into_to_end<R: Read>(
&mut self,
r: &mut Limited<R>,
) -> Result<(), Error>
fn read_xdr_into_to_end<R: Read>( &mut self, r: &mut Limited<R>, ) -> Result<(), Error>
Available on crate feature
std only.Read the XDR into the existing value, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_iter<R: Read>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘ
fn read_xdr_iter<R: Read>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘ
Available on crate feature
std only.Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type. Read more
Sourcefn read_xdr_base64_iter<R: Read>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘ
fn read_xdr_base64_iter<R: Read>( r: &mut Limited<R>, ) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘ
Available on crate feature
base64 only.Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type.
Sourceimpl Serialize for ScpNomination
impl Serialize for ScpNomination
Sourceimpl WriteXdr for ScpNomination
impl WriteXdr for ScpNomination
impl Eq for ScpNomination
impl StructuralPartialEq for ScpNomination