pub struct SignerKeyEd25519SignedPayload {
pub ed25519: Uint256,
pub payload: BytesM<64>,
}Expand description
SignerKeyEd25519SignedPayload is an XDR NestedStruct defined as:
struct
{
/* Public key that must sign the payload. */
uint256 ed25519;
/* Payload to be raw signed by ed25519. */
opaque payload<64>;
}Fields
ed25519: Uint256payload: BytesM<64>Trait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for SignerKeyEd25519SignedPayload
impl<'arbitrary> Arbitrary<'arbitrary> for SignerKeyEd25519SignedPayload
Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourcefn size_hint(depth: usize) -> (usize, Option<usize>)
fn size_hint(depth: usize) -> (usize, Option<usize>)
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourcefn try_size_hint(
depth: usize,
) -> Result<(usize, Option<usize>), MaxRecursionReached>
fn try_size_hint( depth: usize, ) -> Result<(usize, Option<usize>), MaxRecursionReached>
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourceimpl Clone for SignerKeyEd25519SignedPayload
impl Clone for SignerKeyEd25519SignedPayload
Sourcefn clone(&self) -> SignerKeyEd25519SignedPayload
fn clone(&self) -> SignerKeyEd25519SignedPayload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for SignerKeyEd25519SignedPayload
impl Default for SignerKeyEd25519SignedPayload
Sourcefn default() -> SignerKeyEd25519SignedPayload
fn default() -> SignerKeyEd25519SignedPayload
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SignerKeyEd25519SignedPayload
Available on crate features alloc and serde only.
impl<'de> Deserialize<'de> for SignerKeyEd25519SignedPayload
Available on crate features
alloc and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for SignerKeyEd25519SignedPayload
Available on crate feature alloc only.
impl Display for SignerKeyEd25519SignedPayload
Available on crate feature
alloc only.Sourceimpl FromStr for SignerKeyEd25519SignedPayload
Available on crate feature alloc only.
impl FromStr for SignerKeyEd25519SignedPayload
Available on crate feature
alloc only.Sourceimpl Hash for SignerKeyEd25519SignedPayload
impl Hash for SignerKeyEd25519SignedPayload
Sourceimpl JsonSchema for SignerKeyEd25519SignedPayload
Available on crate feature schemars only.
impl JsonSchema for SignerKeyEd25519SignedPayload
Available on crate feature
schemars only.Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for SignerKeyEd25519SignedPayload
impl Ord for SignerKeyEd25519SignedPayload
Sourcefn cmp(&self, other: &SignerKeyEd25519SignedPayload) -> Ordering
fn cmp(&self, other: &SignerKeyEd25519SignedPayload) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SignerKeyEd25519SignedPayload
impl PartialEq for SignerKeyEd25519SignedPayload
Sourcefn eq(&self, other: &SignerKeyEd25519SignedPayload) -> bool
fn eq(&self, other: &SignerKeyEd25519SignedPayload) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SignerKeyEd25519SignedPayload
impl PartialOrd for SignerKeyEd25519SignedPayload
Sourceimpl ReadXdr for SignerKeyEd25519SignedPayload
impl ReadXdr for SignerKeyEd25519SignedPayload
Sourcefn read_xdr<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
std only.Read the XDR and construct the type. Read more
Sourcefn read_xdr_base64<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr_base64<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
base64 only.Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
std only.Read the XDR and construct the type, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_base64_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr_base64_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
base64 only.Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_into<R: Read>(&mut self, r: &mut Limited<R>) -> Result<(), Error>
fn read_xdr_into<R: Read>(&mut self, r: &mut Limited<R>) -> Result<(), Error>
Available on crate feature
std only.Read the XDR and construct the type. Read more
Sourcefn read_xdr_into_to_end<R: Read>(
&mut self,
r: &mut Limited<R>,
) -> Result<(), Error>
fn read_xdr_into_to_end<R: Read>( &mut self, r: &mut Limited<R>, ) -> Result<(), Error>
Available on crate feature
std only.Read the XDR into the existing value, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_iter<R: Read>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘ
fn read_xdr_iter<R: Read>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘ
Available on crate feature
std only.Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type. Read more
Sourcefn read_xdr_base64_iter<R: Read>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘ
fn read_xdr_base64_iter<R: Read>( r: &mut Limited<R>, ) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘ
Available on crate feature
base64 only.Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type.
Sourceimpl Serialize for SignerKeyEd25519SignedPayloadwhere
Self: Display,
impl Serialize for SignerKeyEd25519SignedPayloadwhere
Self: Display,
Sourceimpl WriteXdr for SignerKeyEd25519SignedPayload
impl WriteXdr for SignerKeyEd25519SignedPayload
impl Eq for SignerKeyEd25519SignedPayload
impl StructuralPartialEq for SignerKeyEd25519SignedPayload