pub struct StellarValueProposedValue {
pub tx_set_hash: Hash,
pub previous_ledger_hash: Hash,
pub previous_ledger_version: u32,
pub lc_value_signature: LedgerCloseValueSignature,
}Expand description
StellarValueProposedValue is an XDR NestedStruct defined as:
struct
{
Hash txSetHash;
Hash previousLedgerHash;
uint32 previousLedgerVersion;
LedgerCloseValueSignature lcValueSignature;
}Fields
tx_set_hash: Hashprevious_ledger_hash: Hashprevious_ledger_version: u32lc_value_signature: LedgerCloseValueSignatureTrait Implementations
Sourceimpl<'arbitrary> Arbitrary<'arbitrary> for StellarValueProposedValue
impl<'arbitrary> Arbitrary<'arbitrary> for StellarValueProposedValue
Sourcefn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<Self>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moreSourcefn size_hint(depth: usize) -> (usize, Option<usize>)
fn size_hint(depth: usize) -> (usize, Option<usize>)
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourcefn try_size_hint(
depth: usize,
) -> Result<(usize, Option<usize>), MaxRecursionReached>
fn try_size_hint( depth: usize, ) -> Result<(usize, Option<usize>), MaxRecursionReached>
Get a size hint for how many bytes out of an
Unstructured this type
needs to construct itself. Read moreSourceimpl Clone for StellarValueProposedValue
impl Clone for StellarValueProposedValue
Sourcefn clone(&self) -> StellarValueProposedValue
fn clone(&self) -> StellarValueProposedValue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StellarValueProposedValue
impl Debug for StellarValueProposedValue
Sourceimpl Default for StellarValueProposedValue
impl Default for StellarValueProposedValue
Sourcefn default() -> StellarValueProposedValue
fn default() -> StellarValueProposedValue
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StellarValueProposedValue
impl<'de> Deserialize<'de> for StellarValueProposedValue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for StellarValueProposedValue
impl Hash for StellarValueProposedValue
Sourceimpl JsonSchema for StellarValueProposedValue
impl JsonSchema for StellarValueProposedValue
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for StellarValueProposedValue
impl Ord for StellarValueProposedValue
Sourcefn cmp(&self, other: &StellarValueProposedValue) -> Ordering
fn cmp(&self, other: &StellarValueProposedValue) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StellarValueProposedValue
impl PartialEq for StellarValueProposedValue
Sourcefn eq(&self, other: &StellarValueProposedValue) -> bool
fn eq(&self, other: &StellarValueProposedValue) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for StellarValueProposedValue
impl PartialOrd for StellarValueProposedValue
Sourceimpl ReadXdr for StellarValueProposedValue
Available on crate feature cap_0083 only.
impl ReadXdr for StellarValueProposedValue
Available on crate feature
cap_0083 only.Sourcefn read_xdr<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
std only.Read the XDR and construct the type. Read more
Sourcefn read_xdr_base64<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr_base64<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
base64 only.Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
std only.Read the XDR and construct the type, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_base64_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
fn read_xdr_base64_to_end<R: Read>(r: &mut Limited<R>) -> Result<Self, Error>
Available on crate feature
base64 only.Construct the type from the XDR bytes base64 encoded. Read more
Sourcefn read_xdr_into<R: Read>(&mut self, r: &mut Limited<R>) -> Result<(), Error>
fn read_xdr_into<R: Read>(&mut self, r: &mut Limited<R>) -> Result<(), Error>
Available on crate feature
std only.Read the XDR and construct the type. Read more
Sourcefn read_xdr_into_to_end<R: Read>(
&mut self,
r: &mut Limited<R>,
) -> Result<(), Error>
fn read_xdr_into_to_end<R: Read>( &mut self, r: &mut Limited<R>, ) -> Result<(), Error>
Available on crate feature
std only.Read the XDR into the existing value, and consider it an error if the
read does not completely consume the read implementation. Read more
Sourcefn read_xdr_iter<R: Read>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘ
fn read_xdr_iter<R: Read>(r: &mut Limited<R>) -> ReadXdrIter<&mut R, Self> ⓘ
Available on crate feature
std only.Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type. Read more
Sourcefn read_xdr_base64_iter<R: Read>(
r: &mut Limited<R>,
) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘ
fn read_xdr_base64_iter<R: Read>( r: &mut Limited<R>, ) -> ReadXdrIter<DecoderReader<'_, GeneralPurpose, SkipWhitespace<&mut R>>, Self> ⓘ
Available on crate feature
base64 only.Create an iterator that reads the read implementation as a stream of
values that are read into the implementing type.
Sourceimpl WriteXdr for StellarValueProposedValue
Available on crate feature cap_0083 only.
impl WriteXdr for StellarValueProposedValue
Available on crate feature
cap_0083 only.impl Eq for StellarValueProposedValue
impl StructuralPartialEq for StellarValueProposedValue